<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Proszę wskazać linię, łuk, okrąg lub elipsę</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>Punkt na łuku</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>Proszę wskazać rozwiązanie</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>Brak rozwiązania</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Promień:</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>&amp;Styczna, punkt, promień</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation>Rysuje łuk styczny do obiektu, przez punkt i o danym promieniu</translation>
    </message>
</context>
</TS>
